# Generated by Django 2.2.2 on 2019-06-05 16:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('faq', '0002_faq_order'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='category',
            options={'verbose_name': 'FAQ Category', 'verbose_name_plural': 'FAQ Categories'},
        ),
        migrations.AlterModelOptions(
            name='faq',
            options={'ordering': ['category', 'order'], 'verbose_name': 'FAQ', 'verbose_name_plural': 'FAQs'},
        ),
        migrations.AddField(
            model_name='category',
            name='order',
            field=models.PositiveIntegerField(default=5),
        ),
        migrations.AlterField(
            model_name='faq',
            name='order',
            field=models.PositiveIntegerField(default=5),
        ),
    ]
